==> core-2.2.0.0-sources.jar: io/adbrix/sdk/domain/ABXConstants.java <==
package io.adbrix.sdk.domain;

/**
 * 외부에서 변경되지 않는 상수들
 */
public class ABXConstants {

    public static final String LOGTAG = "abxrm";
    public static final int MAX_KEY_LENGTH = 50;
    public static final String PUSH_NOTIFICATION_CHANNEL_ID = "com.igaworks.v2.core.pushservice"; // temporary channel

    public static final String PUSH_REMOTE_FCM_KEY = "abx:gf:fcm";
    public static final String PUSH_REMOTE_KEY_DEEPLINKJSON = "deep_link_json";
    public static final String PUSH_REMOTE_KEY_DEEPLINKURL = "deep_link_url";
    public static final String PUSH_REMOTE_KEY_ALERT = "alert";
    public static final String PUSH_REMOTE_KEY_CUSTOM_ALERT = "custom_alert";
    public static final String PUSH_REMOTE_KEY_TITLE = "title";
    public static final String PUSH_REMOTE_KEY_BODY = "body";
    public static final String PUSH_REMOTE_KEY_SUMMARY_TEXT = "summary_text";
    public static final String PUSH_REMOTE_KEY_BIG_TITLE = "big_text_title";
    public static final String PUSH_REMOTE_KEY_BIG_BODY = "big_text_body";
    public static final String PUSH_REMOTE_KEY_CAMPAIGN_ID = "abx:gf:campaign_id";
    public static final String PUSH_REMOTE_KEY_CYCLE_TIME = "abx:gf:cycle_time";
    public static final String PUSH_REMOTE_KEY_STEP_ID = "abx:gf:step_id";
    public static final String PUSH_REMOTE_KEY_CAMPAIGN_REVISION_NO = "abx:gf:campaign_revision_no";
    public static final String PUSH_REMOTE_KEY_NOTIFICATION_ID = "notification_id";
    public static final String PUSH_REMOTE_KEY_PUSH_IMAGE = "img";
    public static final String PUSH_REMOTE_KEY_PUSH_LARGE_ICON = "large_icon";
    public static final String PUSH_REMOTE_KEY_PUSH_ALWAYS_SHOWN = "gen_while_run";
    public static final String PUSH_REMOTE_KEY_PUSH_GEN_SOUND = "gen_sound";
    public static final String PUSH_REMOTE_KEY_PUSH_GEN_VIBE = "gen_vibe";
    public static final String PUSH_REMOTE_KEY_PUSH_BUTTONS = "buttons";
    public static final String PUSH_REMOTE_KEY_PUSH_BUTTON1 = "button1";
    public static final String PUSH_REMOTE_KEY_PUSH_BUTTON2 = "button2";
    public static final String PUSH_REMOTE_DATA = "remote_push_data";

    private ABXConstants() {
    }
}

==> core-2.3.0.1-sources.jar: io/adbrix/sdk/domain/ABXConstants.java <==
package io.adbrix.sdk.domain;

/**
 * 외부에서 변경되지 않는 상수들
 */
public class ABXConstants {

    public static final String LOGTAG = "abxrm";
    public static final int MAX_KEY_LENGTH = 50;
    public static final String PUSH_NOTIFICATION_CHANNEL_ID = "com.igaworks.v2.core.pushservice"; // temporary channel

    public static final String PUSH_REMOTE_FCM_KEY = "abx:gf:fcm";
    public static final String PUSH_REMOTE_KEY_DEEPLINKJSON = "deep_link_json";
    public static final String PUSH_REMOTE_KEY_DEEPLINKURL = "deep_link_url";
    public static final String PUSH_REMOTE_KEY_ALERT = "alert";
    public static final String PUSH_REMOTE_KEY_CUSTOM_ALERT = "custom_alert";
    public static final String PUSH_REMOTE_KEY_TITLE = "title";
    public static final String PUSH_REMOTE_KEY_BODY = "body";
    public static final String PUSH_REMOTE_KEY_SUMMARY_TEXT = "summary_text";
    public static final String PUSH_REMOTE_KEY_BIG_TITLE = "big_text_title";
    public static final String PUSH_REMOTE_KEY_BIG_BODY = "big_text_body";
    public static final String GROWTH_EVENT_KEY_CAMPAIGN_ID = "abx:gf:campaign_id";
    public static final String GROWTH_EVENT_KEY_CYCLE_TIME = "abx:gf:cycle_time";
    public static final String GROWTH_EVENT_KEY_STEP_ID = "abx:gf:step_id";
    public static final String GROWTH_EVENT_KEY_CAMPAIGN_REVISION_NO = "abx:gf:campaign_revision_no";
    public static final String PUSH_REMOTE_KEY_NOTIFICATION_ID = "notification_id";
    public static final String PUSH_REMOTE_KEY_PUSH_IMAGE = "img";
    public static final String PUSH_REMOTE_KEY_PUSH_LARGE_ICON = "large_icon";
    public static final String PUSH_REMOTE_KEY_PUSH_ALWAYS_SHOWN = "gen_while_run";
    public static final String PUSH_REMOTE_KEY_PUSH_GEN_SOUND = "gen_sound";
    public static final String PUSH_REMOTE_KEY_PUSH_GEN_VIBE = "gen_vibe";
    public static final String PUSH_REMOTE_KEY_PUSH_BUTTONS = "buttons";
    public static final String PUSH_REMOTE_KEY_PUSH_BUTTON1 = "button1";
    public static final String PUSH_REMOTE_KEY_PUSH_BUTTON2 = "button2";
    public static final String PUSH_REMOTE_DATA = "remote_push_data";

    private ABXConstants() {
    }
}
